==> haskell-hasql-transaction-1.0.1.1-411.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-transaction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-transaction
version:              1.0.1.1
visibility:           public
id:                   hasql-transaction-1.0.1.1-BmgVJCtyClDsf99umbbnq
key:                  hasql-transaction-1.0.1.1-BmgVJCtyClDsf99umbbnq
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-transaction
synopsis:
    Composable abstraction over retryable transactions for Hasql

category:             Hasql, Database, PostgreSQL
abi:                  895a7786cd2638be66008b925a15d251
exposed:              True
exposed-modules:      Hasql.Transaction Hasql.Transaction.Sessions
hidden-modules:
    Hasql.Transaction.Private.Prelude Hasql.Transaction.Private.Model
    Hasql.Transaction.Private.SQL Hasql.Transaction.Private.Statements
    Hasql.Transaction.Private.Sessions
    Hasql.Transaction.Private.Transaction

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hasql-transaction-1.0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hasql-transaction-1.0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hasql-transaction-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-transaction
hs-libraries:         HShasql-transaction-1.0.1.1-BmgVJCtyClDsf99umbbnq
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    bytestring-tree-builder-0.2.7.13-1q3iZsjo0U96qEOokA5GwK
    contravariant-1.5.5-JUOgBPNZkO18h7ix7HMuaW
    contravariant-extras-0.3.5.4-3woyg6AJRP6Lk666ZeP5zR
    hasql-1.5.0.5-D13dwG1Hnoj5UOBosN4Mcc mtl-2.3.1 transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-hasql-transaction/html/hasql-transaction.haddock

haddock-html:         /usr/share/doc/haskell-hasql-transaction/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-transaction-1.0.1.1-412-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-transaction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-transaction
version:              1.0.1.1
visibility:           public
id:                   hasql-transaction-1.0.1.1-Il4qgXOnyoL5xvlkWio9Z0
key:                  hasql-transaction-1.0.1.1-Il4qgXOnyoL5xvlkWio9Z0
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-transaction
synopsis:
    Composable abstraction over retryable transactions for Hasql

category:             Hasql, Database, PostgreSQL
abi:                  3a2dae5a487cd608b68a79a1aa779bc5
exposed:              True
exposed-modules:      Hasql.Transaction Hasql.Transaction.Sessions
hidden-modules:
    Hasql.Transaction.Private.Prelude Hasql.Transaction.Private.Model
    Hasql.Transaction.Private.SQL Hasql.Transaction.Private.Statements
    Hasql.Transaction.Private.Sessions
    Hasql.Transaction.Private.Transaction

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hasql-transaction-1.0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hasql-transaction-1.0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hasql-transaction-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-transaction
hs-libraries:         HShasql-transaction-1.0.1.1-Il4qgXOnyoL5xvlkWio9Z0
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    bytestring-tree-builder-0.2.7.13-FwMdcdGvXWgJQbnsWeUFWv
    contravariant-1.5.5-JUOgBPNZkO18h7ix7HMuaW
    contravariant-extras-0.3.5.4-3woyg6AJRP6Lk666ZeP5zR
    hasql-1.5.0.5-D56QxJSATLi7EO6Br9LDFG mtl-2.3.1 transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-hasql-transaction/html/hasql-transaction.haddock

haddock-html:         /usr/share/doc/haskell-hasql-transaction/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
